import { applyMiddleware, createStore, compose } from 'redux';
import { routerMiddleware } from 'connected-react-router';
import { createInjectorsEnhancer, forceReducerReload } from 'redux-injectors';
import createSagaMiddleware from 'redux-saga';
import { History } from 'history';
import { composeWithDevTools } from 'redux-devtools-extension';

import createReducer from './Redux/Reducers/reducer';
import { InjectedStore, ApplicationRootState } from './types';

//import rootreducer



export default function configureStore(
  initialState: ApplicationRootState | {} = {},
  history: History,
) {
  const reduxSagaMonitorOptions = {};
  const sagaMiddleware = createSagaMiddleware(reduxSagaMonitorOptions);
  const { run: runSaga } = sagaMiddleware;

  // Create the store with two middlewares
  // 1. sagaMiddleware: Makes redux-sagas work
  // 2. routerMiddleware: Syncs the location/URL path to the state
  const middlewares = [sagaMiddleware, routerMiddleware(history)];

  const enhancers = [
    applyMiddleware(...middlewares),
    createInjectorsEnhancer({
      createReducer,
      runSaga,
    }),
  ];

  let enhancer;
  if (process.env.NODE_ENV !== 'production' && typeof window === 'object') {
    enhancer = composeWithDevTools(...enhancers);
  } else {
    enhancer = compose(...enhancers);
  }

  let rootReducer;
  const store = createStore(
    createReducer(),
    enhancer,
    rootReducer,


  ) as InjectedStore;

  // Extensions
  store.runSaga = sagaMiddleware.run;
  store.injectedReducers = {}; // Reducer registry
  store.injectedSagas = {}; // Saga registry

  // Make reducers hot reloadable, see http://mxs.is/googmo
  /* istanbul ignore next */
  if (module.hot) {
    module.hot.accept('./Redux/Reducers/reducer', () => {
      forceReducerReload(store);
    });
  }

  return store;
}

// import {createStore, applyMiddleware} from 'redux';
// import rootReducer from './Redux/Reducers/reducer';
// import reduxSaga from 'redux-saga';
// import rootSaga from './Redux/Sagas';
// import { History } from 'history';
// import { InjectedStore, ApplicationRootState } from './types';


// export const getStore  = () =>{
//   // const initialState = {};
//   const reduxSagaMiddleware= reduxSaga();
//   const store = createStore(rootReducer, initialState, applyMiddleware(reduxSagaMiddleware));
//   reduxSagaMiddleware.run(rootSaga)
//   return store;
// }